@@ -425,7 +425,7 @@ where
 
     #[emitter]
     fn emit_num(&mut self, n: &Num) -> Result {
-        self.wr.write_raw(Some(n.span), &n.value.to_string())?;
+        self.wr.write_raw(Some(n.span), &n.raw)?;
     }
 
     #[emitter]
@@ -494,8 +494,8 @@ where
                 Token::RBracket => {
                     punct!(self, span, "]");
                 }
-                Token::Num(n) => {
-                    self.wr.write_raw(Some(span), &n.value.to_string())?;
+                Token::Num { raw, .. } => {
+                    self.wr.write_raw(Some(span), raw)?;
                 }
                 Token::Ident { raw, .. } => {
                     self.wr.write_raw(Some(n.span), &raw)?;
@@ -690,7 +690,7 @@ where
             UnitKind::Px => Cow::Owned("px".into()),
             UnitKind::Custom(s) => Cow::Borrowed(s),
         };
-        self.wr.write_ident(Some(n.span), &s, true)?;
+        self.wr.write_raw(Some(n.span), &s)?;
     }
 
     #[emitter]
